@@ -18,22 +18,12 @@ class   Phial(object):
 
     def __default_debug_404(self, error):
         from flask import request
-        return render_template('phial/default_debug_404.html', error = error, method=request.method, path=request.path, lst_route = self.__flask.url_map.iter_rules()), 404
+        from . import __version__ as phial_version
+        return render_template('phial/default_debug_404.html', phial_version = phial_version, error = error, method=request.method, path=request.path, lst_route = self.__flask.url_map.iter_rules()), 404
 
     def __default_welcome(self):
-        lst_version = [
-            ('Python version', '.'.join(map(lambda x : str(x), sys.version_info[0:3]))),
-            ]
-        for m in [('Phial', 'phial'), ('Flask', 'flask'), ('Jinja', 'jinja2'), ('Peewee', 'peewee'), ('IPython', 'IPython'), ('Celery', 'celery'), ('Redis', 'redis'), ('SQLite', 'sqlite3'), ('MySQL', 'MySQLdb'), ('PyMySQL', 'pymsql'), ('Babel', 'babel'), ('WTForms', 'wtforms')]:
-            try:
-                hdl = __import__(m[1])
-                ver = getattr(hdl, '__version__', None)
-                if ver is None:
-                    ver = getattr(hdl, 'version', 'Unknown')
-            except ImportError:
-                ver = None
-            lst_version.append((m[0], ver))
-        return render_template('phial/default_welcome.html', phial = self, lst_version = lst_version)
+        from . import __version__ as phial_version
+        return render_template('phial/default_welcome.html', phial_version = phial_version)
 
     def initApp(self, **kwargs):
         # Initialize Flask
